@@ -16,6 +16,7 @@
 EQRN_fit_restart <- function(X, y, intermediate_quantiles, interm_lvl, number_fits=3, ..., seed=NULL, data_type=c("iid","seq")){#TODO: force_trainloss_select arg
   #
   data_type <- match.arg(data_type)
+  ensure_backend_installed()
   if(number_fits<1){stop("'number_fits' must be at least 1 in 'EQRN_fit_restart'.")}
   
   if(!is.null(seed)){torch::torch_manual_seed(seed)}
@@ -130,6 +131,7 @@ EQRN_fit <- function(X, y, intermediate_quantiles, interm_lvl, shape_fixed=FALSE
                      X_valid=NULL, y_valid=NULL, quant_valid=NULL, lr_decay=1, patience_decay=n_epochs, min_lr=0, patience_stop=n_epochs,
                      tol=1e-6, orthogonal_gpd=TRUE, patience_lag=1, optim_met="adam", seed=NULL, verbose=2, device=default_device()){
   
+  ensure_backend_installed()
   if(!is.null(seed)){torch::torch_manual_seed(seed)}
   
   data_excesses <- get_excesses(X=X, y=y, quantiles=intermediate_quantiles,
@@ -383,7 +385,6 @@ EQRN_predict_internal <- function(fit_eqrn, X, prob_lvl_predict, intermediate_qu
 #'
 #' @return Named list containing: `"scales"` and `"shapes"` as numerical vectors of length `nrow(X)`.
 #' @export
-#' @import torch
 #' @importFrom coro loop
 EQRN_predict_params <- function(fit_eqrn, X, intermediate_quantiles=NULL, return_parametrization=c("classical","orthogonal"),
                                 interm_lvl=fit_eqrn$interm_lvl, device=default_device()){
@@ -486,7 +487,6 @@ excess_probability.EQRN_iid <- function(object, ...){
 #' @return Negative GPD log likelihood of the conditional EQRN predicted parameters
 #' over the response exceedances over the intermediate quantiles.
 #' @export
-#' @import torch
 #' @importFrom coro loop
 compute_EQRN_GPDLoss <- function(fit_eqrn, X, y, intermediate_quantiles=NULL, interm_lvl=fit_eqrn$interm_lvl, device=default_device()){#TODO: internal_fct shared with train
   if(interm_lvl!=fit_eqrn$interm_lvl){stop("EQRN intermediate quantiles interm_lvl does not match in train and predict.")}
@@ -527,7 +527,6 @@ compute_EQRN_GPDLoss <- function(fit_eqrn, X, y, intermediate_quantiles=NULL, in
 #' @param device (optional) A [torch::torch_device()]. Defaults to [default_device()].
 #'
 #' @return A `torch::nn_module` network used to regress the GPD parameters in [EQRN_fit()].
-#' @import torch
 #' 
 #' @keywords internal
 instantiate_EQRN_network <- function(net_structure, shape_fixed, D_in, hidden_fct, p_drop=0,
@@ -575,7 +574,6 @@ instantiate_EQRN_network <- function(net_structure, shape_fixed, D_in, hidden_fc
 #' @param optim_met DEPRECATED. Optimization algorithm to use during training. `"adam"` is the default.
 #'
 #' @return A `torch::optimizer` object used in [EQRN_fit()] for training.
-#' @import torch
 #' 
 #' @keywords internal
 setup_optimizer <- function(network, learning_rate, L2_pen, hidden_fct, optim_met="adam"){
@@ -610,7 +608,6 @@ setup_optimizer <- function(network, learning_rate, L2_pen, hidden_fct, optim_me
 #' @param decay_rate Learning rate decay factor.
 #'
 #' @return The `optimizer` with a decayed learning rate.
-#' @import torch
 #' 
 #' @keywords internal
 decay_learning_rate <- function(optimizer, decay_rate){
@@ -633,7 +630,6 @@ decay_learning_rate <- function(optimizer, decay_rate){
 #'
 #' @return No return value.
 #' @export
-#' @import torch
 #' @importFrom utils packageVersion
 EQRN_save <- function(fit_eqrn, path, name=NULL, no_warning=TRUE){
   if(is.null(name)){
@@ -666,9 +662,9 @@ EQRN_save <- function(fit_eqrn, path, name=NULL, no_warning=TRUE){
 #'
 #' @return The loaded `"EQRN"` model.
 #' @export
-#' @import torch
 #' @importFrom utils packageVersion
 EQRN_load <- function(path, name=NULL, device=default_device(), ...){
+  ensure_backend_installed()
   if(substr(path, nchar(path), nchar(path)) != "/"){
     fpath <- paste0(path, "/")
   } else {
@@ -706,7 +702,6 @@ EQRN_load <- function(path, name=NULL, device=default_device(), ...){
 #' @return The GPD loss over the batch between the network output and the observed responses as a `torch::Tensor`,
 #' whose dimensions depend on `return_agg`.
 #' @export
-#' @import torch
 loss_GPD_tensor <- function(out, y, orthogonal_gpd=TRUE, shape_penalty=0, prior_shape=NULL, return_agg=c("mean", "sum", "vector", "nanmean", "nansum")){
   return_agg <- match.arg(return_agg)
   s <- torch::torch_split(out, 1, dim = 2)
@@ -860,9 +855,12 @@ perform_scaling <- function(X, X_scaling=NULL, scale_features=TRUE, stat_attr=FA
 #'
 #' @return Returns `torch::torch_device("cuda")` if `torch::cuda_is_available()`, or `torch::torch_device("cpu")` otherwise.
 #' @export
-#' @import torch
 #'
-#' @examples device <- default_device()
+#' @examples 
+#' if(backend_is_installed()){
+#'   device <- default_device()
+#'   print(device)
+#' }
 default_device <- function(){
   if(torch::cuda_is_available()) {
     device <- torch::torch_device("cuda")
